@@ -168,7 +168,7 @@ class bxReposBaseDir_libOverview(icm.Cmnd):
             argChoices.pop(0)
             actions = argChoices
         for each in actions:
-            print each
+            print(each)
             if interactive:
                 #print( str( __doc__ ) )  # This is the Summary: from the top doc-string
                 #version(interactive=True)
@@ -1734,7 +1734,7 @@ class pbdRootsForPlatform(icm.Cmnd):
             gid = grp.getgrnam(bxReposGroupName).gr_gid
             os.chown(rootDir, uid, gid)
 
-            os.chmod(rootDir, 0775)            
+            os.chmod(rootDir, 0o775)            
 
             outcome = icm.subProc_bash("""\
 ls -ld  {rootDir}"""
