@@ -168,7 +168,7 @@ class bxpBaseDir_libOverview(icm.Cmnd):
             argChoices.pop(0)
             actions = argChoices
         for each in actions:
-            print each
+            print(each)
             if interactive:
                 #print( str( __doc__ ) )  # This is the Summary: from the top doc-string
                 #version(interactive=True)
@@ -1066,22 +1066,22 @@ def pbdDict_bleeRoot(
     symLink('blee/env',
             'git/bxRepos/blee/env'
             )
-   symLink('blee/env2',
+    symLink('blee/env2',
             'git/bxRepos/blee/env2'
             )
-   symLink('blee/doom-emacs-framework',
+    symLink('blee/doom-emacs-framework',
             'git/bxRepos/blee/doom-emacs-framework'
             )
-   symLink('blee/doom-emacs-init',
+    symLink('blee/doom-emacs-init',
             'git/bxRepos/blee/doom-emacs-init'
             )
-   symLink('blee/doom-blee-init',
+    symLink('blee/doom-blee-init',
             'git/bxRepos/blee/doom-blee-init'
             )
-   symLink('blee/doom-base',
+    symLink('blee/doom-base',
             'git/bxRepos/blee/doom-base'
             )
-   symLink('blee/doom-blee-base',
+    symLink('blee/doom-blee-base',
             'git/bxRepos/blee/doom-blee-base'
             )
 
@@ -1532,7 +1532,7 @@ class pbdRootsForPlatform(icm.Cmnd):
             gid = grp.getgrnam(bisosGroupName).gr_gid
             os.chown(rootDir, uid, gid)
 
-            os.chmod(rootDir, 0775)            
+            os.chmod(rootDir, 0o775)            
 
             outcome = icm.subProc_bash("""\
 ls -ld  {rootDir}"""
